@@ -3,15 +3,13 @@ from __future__ import absolute_import, unicode_literals
 from django.conf import settings
 from django.core.urlresolvers import reverse
 from django.db import models
-from django.db.models import signals, Q
+from django.db.models import Q
 from django.template.defaultfilters import slugify
 from django.utils import timezone
 from django.utils.encoding import python_2_unicode_compatible
 from django.utils.translation import ugettext_lazy as _, ugettext
 
-from feincms import settings as feincms_settings
 from feincms import translations
-from feincms.management.checker import check_database_schema
 from feincms.models import Base
 from feincms.module.mixins import ContentModelMixin
 from feincms.utils.managers import ActiveAwareContentManagerMixin
@@ -83,7 +81,7 @@ EntryManager.add_to_active_filters(
     key='cleared')
 
 EntryManager.add_to_active_filters(
-    lambda queryset: queryset.filter(published_on__lte=timezone.now),
+    lambda queryset: queryset.filter(published_on__lte=timezone.now()),
     key='published_on_past')
 
 
@@ -153,14 +151,3 @@ class Entry(Base, ContentModelMixin):
     def register_extension(cls, register_fn):
         from .modeladmins import EntryAdmin
         register_fn(cls, EntryAdmin)
-
-
-try:
-    _do_check = feincms_settings.FEINCMS_CHECK_DATABASE_SCHEMA
-except:
-    _do_check = True
-
-if _do_check:
-    signals.post_syncdb.connect(
-        check_database_schema(Entry, __name__),
-        weak=False)
