@@ -1,3 +1,5 @@
+from __future__ import absolute_import, unicode_literals
+
 from elephantblog.models import Category, Entry
 
 
@@ -16,17 +18,24 @@ def entry_list_lookup_related(entry_qs):
             entry_dict[content.parent_id].first_image = content
 
     m2mfield = Entry._meta.get_field('categories')
-    for category in Category.objects.filter(blogentries__in=entry_dict.keys()).extra(
-            select={
-                'entry_id': '%s.%s' % (m2mfield.m2m_db_table(), m2mfield.m2m_column_name()),
-            }):
+    categories = Category.objects.filter(
+        blogentries__in=entry_dict.keys(),
+    ).extra(
+        select={
+            'entry_id': '%s.%s' % (
+                m2mfield.m2m_db_table(), m2mfield.m2m_column_name()),
+        },
+    )
+
+    for category in categories:
         entry = entry_dict[category.entry_id]
-        if not hasattr(entry, 'fetched_categories'): entry.fetched_categories = []
+        if not hasattr(entry, 'fetched_categories'):
+            entry.fetched_categories = []
         entry.fetched_categories.append(category)
 
 
 def same_category_entries(entry):
     """ @return: all entries that have at least one category in common """
     return Entry.objects.active().filter(
-                                        categories__in=entry.categories.all())\
-                                        .exclude(pk=entry.pk).distinct()
\ No newline at end of file
+        categories__in=entry.categories.all(),
+    ).exclude(pk=entry.pk).distinct()
