@@ -114,7 +114,8 @@ class DayArchiveView(
 
 
 class DateDetailView(
-        ContentObjectMixin, ElephantblogMixin, dates.DateDetailView):
+        TranslationMixin, ContentObjectMixin, ElephantblogMixin,
+        dates.DateDetailView):
     paginator_class = paginator.Paginator
     paginate_by = PAGINATE_BY
     month_format = '%m'
@@ -125,7 +126,7 @@ class DateDetailView(
         if (self.request.user.is_authenticated() and self.request.user.is_staff
                 and self.request.GET.get('eb_preview')):
             return self.entry_class.objects.all()
-        return self.entry_class.objects.active()
+        return super(DateDetailView, self).get_queryset()
 
     def _make_date_lookup_arg(self, value):
         """
@@ -207,8 +208,33 @@ class DateDetailView(
         self.args = args
         self.kwargs = kwargs
         self.object = self.get_object()
+        self.lookup_related()
         return self.handler(request, *args, **kwargs)
 
+    def lookup_related(self):
+        """
+        This method mirrors ``entry_list_lookup_related``, and assigns
+        ``first_richtext`` and ``first_image`` to the elephantblog entry
+        if suitable contents can be found.
+        """
+        from feincms.content.medialibrary.models import MediaFileContent
+        from feincms.content.richtext.models import RichTextContent
+
+        try:
+            self.object.first_image = [
+                mediafile
+                for mediafile in self.object.content.all_of_type(
+                    MediaFileContent)
+                if mediafile.mediafile.type == 'image'][0]
+        except IndexError:
+            pass
+
+        try:
+            self.object.first_richtext = self.object.content.all_of_type(
+                RichTextContent)[0]
+        except IndexError:
+            pass
+
     def get_next_or_none(self):
         try:
             return self.get_queryset().filter(
